##  Description
The fact sheet type business context can be modeled for a more granular representation of an organization's business architecture and is indispensable for some use cases (e.g., ERP transformation).
Overview of all relations to/from business context:
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275587637a4410148a85f594cbe8d150_LowRes.png)
